==> seedsui-react-2.5.7.tgz: package/es/Timeline/Timeline.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Dot from './../Dot';

var Timeline = (_temp = _class = function (_Component) {
  _inherits(Timeline, _Component);

  function Timeline(props) {
    _classCallCheck(this, Timeline);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Timeline.prototype.render = function render() {
    var _props = this.props,
        list = _props.list,
        className = _props.className,
        style = _props.style,
        lineParams = _props.lineParams,
        badgeParams = _props.badgeParams,
        dotParams = _props.dotParams,
        others = _objectWithoutProperties(_props, ['list', 'className', 'style', 'lineParams', 'badgeParams', 'dotParams']);

    if (!list) return null;
    var listDOM = list.map(function (item, index) {
      return React.createElement(
        'div',
        { key: index, className: 'timeline-case' + (item.active ? ' active' : '') },
        React.createElement(
          'div',
          _extends({}, badgeParams, { className: 'timeline-badge' + (badgeParams.className ? ' ' + badgeParams.className : '') }),
          item.icon || React.createElement(Dot, _extends({}, dotParams, { className: item.active ? 'active ' + dotParams.className : dotParams.className }))
        ),
        item.content,
        item.children
      );
    });
    return React.createElement(
      'div',
      _extends({ className: 'timeline' + (className ? ' ' + className : ''), style: style }, others),
      React.createElement('span', _extends({}, lineParams, { className: 'timeline-line' + (lineParams.className ? ' ' + lineParams.className : '') })),
      listDOM
    );
  };

  return Timeline;
}(Component), _class.defaultProps = {
  lineParams: {},
  badgeParams: {},
  dotParams: {
    className: ''
  }
}, _temp);
export { Timeline as default };
Timeline.propTypes = process.env.NODE_ENV !== "production" ? {
  list: PropTypes.array, // [{content: node,icon: node(默认Dot), active: bool, children: node}]
  className: PropTypes.string,
  style: PropTypes.object,

  lineParams: PropTypes.object,

  badgeParams: PropTypes.object,

  dotParams: PropTypes.object
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Timeline/Timeline.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Timeline = (_temp = _class = function (_Component) {
  _inherits(Timeline, _Component);

  function Timeline(props) {
    _classCallCheck(this, Timeline);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Timeline.prototype.render = function render() {
    var _props = this.props,
        list = _props.list,
        _props$lineAttribute = _props.lineAttribute,
        lineAttribute = _props$lineAttribute === undefined ? {} : _props$lineAttribute,
        _props$badgeAttribute = _props.badgeAttribute,
        badgeAttribute = _props$badgeAttribute === undefined ? {} : _props$badgeAttribute,
        _props$dotAttribute = _props.dotAttribute,
        dotAttribute = _props$dotAttribute === undefined ? {} : _props$dotAttribute,
        others = _objectWithoutProperties(_props, ['list', 'lineAttribute', 'badgeAttribute', 'dotAttribute']);

    if (!list) return null;
    var listDOM = list.map(function (item, index) {
      return React.createElement(
        'div',
        { key: index, className: 'timeline-case' + (item.active ? ' active' : '') },
        React.createElement(
          'div',
          _extends({}, badgeAttribute, { className: 'timeline-badge' + (badgeAttribute.className ? ' ' + badgeAttribute.className : '') }),
          item.icon || React.createElement('i', _extends({}, dotAttribute, { className: 'timeline-dot' + (dotAttribute.className ? ' ' + dotAttribute.className : '') }))
        ),
        item.content,
        item.contentHTML && React.createElement('div', { dangerouslySetInnerHTML: { __html: item.contentHTML } })
      );
    });
    return React.createElement(
      'div',
      _extends({}, others, { className: 'timeline' + (others.className ? ' ' + others.className : '') }),
      React.createElement('span', _extends({}, lineAttribute, { className: 'timeline-line' + (lineAttribute.className ? ' ' + lineAttribute.className : '') })),
      listDOM
    );
  };

  return Timeline;
}(Component), _class.defaultProps = {}, _temp);
export { Timeline as default };
Timeline.propTypes = process.env.NODE_ENV !== "production" ? {
  list: PropTypes.array, // [{content: node, contentHTML: string, icon: node(默认Dot), active: bool}]

  lineAttribute: PropTypes.object,
  badgeAttribute: PropTypes.object,
  dotAttribute: PropTypes.object
} : {};
